==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/kadu-core/configuration/configuration-holder.h <==
/*
 * %kadu copyright begin%
 * Copyright 2008, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
 * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
 * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONFIGURATION_HOLDER_H
#define CONFIGURATION_HOLDER_H

#include <QtCore/QObject>

class ConfigurationHolder : public QObject
{
	Q_OBJECT
	Q_DISABLE_COPY(ConfigurationHolder)

	static QList<ConfigurationHolder *> Instances;

protected:
	ConfigurationHolder();
	virtual ~ConfigurationHolder();

public:
	static const QList<ConfigurationHolder *> & instances() { return Instances; }

	virtual void configurationUpdated() = 0;

};

#endif // CONFIGURATION_HOLDER_H

==> kadu_1.2.orig.tar.bz2: kadu-1.2/kadu-core/configuration/configuration-holder.h <==
/*
 * %kadu copyright begin%
 * Copyright 2008, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
 * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
 * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONFIGURATION_HOLDER_H
#define CONFIGURATION_HOLDER_H

#include <QtCore/QObject>

#include "exports.h"

class KADUAPI ConfigurationHolder : public QObject
{
	Q_OBJECT
	Q_DISABLE_COPY(ConfigurationHolder)

	static QList<ConfigurationHolder *> Instances;

protected:
	ConfigurationHolder();
	virtual ~ConfigurationHolder();

public:
	static const QList<ConfigurationHolder *> & instances() { return Instances; }

	virtual void configurationUpdated() = 0;

};

#endif // CONFIGURATION_HOLDER_H
